@@ -25,7 +25,6 @@
 #include "settings_p.h"
 
 #include <QCheckBox>
-#include <QLayout>
 #include <QListWidget>
 #include <QLineEdit>
 #include <QListWidgetItem>
@@ -171,7 +170,7 @@ void ConfigWidget::slotIgnoreWordRemoved()
 {
     QStringList ignoreList = d->loader->settings()->currentIgnoreList();
     const QList<QListWidgetItem *> selectedItems = d->ui.ignoreListWidget->selectedItems();
-    Q_FOREACH (const QListWidgetItem *item, selectedItems) {
+    for (const QListWidgetItem *item : selectedItems) {
         ignoreList.removeAll(item->text());
     }
     d->loader->settings()->setCurrentIgnoreList(ignoreList);
